==> ogre-docs-1.11.1-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/group___g_l_support.js <==
var group___g_l_support =
[
    [ "GLNativeSupport", "class_ogre_1_1_g_l_native_support.html", [
      [ "ExtensionList", "class_ogre_1_1_g_l_native_support.html#a275d33f9c513afe02bbf054c648d3527", null ],
      [ "ContextProfile", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626", [
        [ "CONTEXT_CORE", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a3733c7b98d92d0d5f41b7ee002838bb3", null ],
        [ "CONTEXT_COMPATIBILITY", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a9999894be166446034357f432cda906a", null ],
        [ "CONTEXT_ES", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a4c0ba704d3a11d103d93deb6dd8a0492", null ]
      ] ],
      [ "GLNativeSupport", "class_ogre_1_1_g_l_native_support.html#a5c55ceef7d8a3a2b4f7b1d1494067934", null ],
      [ "~GLNativeSupport", "class_ogre_1_1_g_l_native_support.html#a53fa78d28a245ed78e41103dd8c4d0d6", null ],
      [ "addConfig", "class_ogre_1_1_g_l_native_support.html#a2f012bb098a2d50f7a2a7aec496651d3", null ],
      [ "setConfigOption", "class_ogre_1_1_g_l_native_support.html#a0990c160adec7410132e717046aea3d0", null ],
      [ "validateConfig", "class_ogre_1_1_g_l_native_support.html#a31fcc47bf6fa6efe769c002fb2c74176", null ],
      [ "parseOptions", "class_ogre_1_1_g_l_native_support.html#a7279783401c1fb941b6cb2b875c761fc", null ],
      [ "newWindow", "class_ogre_1_1_g_l_native_support.html#a0e4936530d0b8a1b5ce3ae24fe579a04", null ],
      [ "createPBuffer", "class_ogre_1_1_g_l_native_support.html#a23d24566aed67c352f9da3f9ebc45810", null ],
      [ "getProcAddress", "class_ogre_1_1_g_l_native_support.html#a22db2ba12d9fc2d64ac41b1868b31efc", null ],
      [ "checkExtension", "class_ogre_1_1_g_l_native_support.html#a91d9e3a7b643d399b407355b0e1128ed", null ],
      [ "getDisplayMonitorCount", "class_ogre_1_1_g_l_native_support.html#af55898ae757c2430a956a90e244ce308", null ],
      [ "start", "class_ogre_1_1_g_l_native_support.html#aa5b31e56e635d00d2c819aa265356e1b", null ],
      [ "stop", "class_ogre_1_1_g_l_native_support.html#a593753502e089257872d2d3880be9b9c", null ],
      [ "getConfigOptions", "class_ogre_1_1_g_l_native_support.html#a6742514be355ba5cdc682b4fcf7e98db", null ]
    ] ]
];

==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/group___g_l_support.js <==
var group___g_l_support =
[
    [ "GLNativeSupport", "class_ogre_1_1_g_l_native_support.html", [
      [ "VideoModes", "class_ogre_1_1_g_l_native_support.html#ab1918dfe87a650d07c4d2b45f003ac29", null ],
      [ "ExtensionList", "class_ogre_1_1_g_l_native_support.html#a275d33f9c513afe02bbf054c648d3527", null ],
      [ "ContextProfile", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626", [
        [ "CONTEXT_CORE", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a3733c7b98d92d0d5f41b7ee002838bb3", null ],
        [ "CONTEXT_COMPATIBILITY", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a9999894be166446034357f432cda906a", null ],
        [ "CONTEXT_ES", "class_ogre_1_1_g_l_native_support.html#a661a3d79709af2486b7b5437afde3626a4c0ba704d3a11d103d93deb6dd8a0492", null ]
      ] ],
      [ "GLNativeSupport", "class_ogre_1_1_g_l_native_support.html#a5c55ceef7d8a3a2b4f7b1d1494067934", null ],
      [ "~GLNativeSupport", "class_ogre_1_1_g_l_native_support.html#a53fa78d28a245ed78e41103dd8c4d0d6", null ],
      [ "newWindow", "class_ogre_1_1_g_l_native_support.html#a0e4936530d0b8a1b5ce3ae24fe579a04", null ],
      [ "createPBuffer", "class_ogre_1_1_g_l_native_support.html#a23d24566aed67c352f9da3f9ebc45810", null ],
      [ "getProcAddress", "class_ogre_1_1_g_l_native_support.html#a22db2ba12d9fc2d64ac41b1868b31efc", null ],
      [ "checkExtension", "class_ogre_1_1_g_l_native_support.html#a91d9e3a7b643d399b407355b0e1128ed", null ],
      [ "getDisplayMonitorCount", "class_ogre_1_1_g_l_native_support.html#af55898ae757c2430a956a90e244ce308", null ],
      [ "start", "class_ogre_1_1_g_l_native_support.html#aa5b31e56e635d00d2c819aa265356e1b", null ],
      [ "stop", "class_ogre_1_1_g_l_native_support.html#a593753502e089257872d2d3880be9b9c", null ],
      [ "getConfigOptions", "class_ogre_1_1_g_l_native_support.html#a49cadf8b5304632a28d34f4687d75808", null ],
      [ "getFSAALevels", "class_ogre_1_1_g_l_native_support.html#a1b390adc7287356650b6508fea305c20", null ],
      [ "getVideoModes", "class_ogre_1_1_g_l_native_support.html#a6f9f4c06381c7766613241f4730ff849", null ]
    ] ]
];
